@@ -55,13 +55,13 @@
 #include <QSvgRenderer>
 
 // include files for KDE
-#include <kiconloader.h>
-#include <kmessagebox.h>
+#include <KIconLoader>
+#include <KMessageBox>
 #include <KLocalizedString>
-#include <kconfig.h>
-#include <kstandardgameaction.h>
-#include <kstandardaction.h>
-#include <kactioncollection.h>
+#include <KConfig>
+#include <KStandardGameAction>
+#include <KStandardAction>
+#include <KActionCollection>
 #include "ksirkskineditor_debug.h"
 #include <phonon/mediaobject.h>
 #include <KToolBar>
