@@ -35,9 +35,9 @@
 
 #include <KLocalizedString>
 #include "ksirkskineditor_debug.h"
-#include <kmessagebox.h>
-#include <kconfig.h>
-#include <kconfiggroup.h>
+#include <KMessageBox>
+#include <KConfig>
+#include <KConfigGroup>
 
 namespace KsirkSkinEditor
 {
